==> mongodb-ui-components-4.2.1.tgz: package/src/nav/js/nav-middle/index.js <==
import React, {Component} from 'react'
import { hamburgerIcon } from '../nav-icons'

export default class MiddlePanel extends Component {
  constructor (props) {
    super(props)

    this.state = {
      isMobile: this.props.isMobile,
      activeSection: this.props.activeSection || -1
    }

    this.renderSection = this.renderSection.bind(this)
  }

  componentWillReceiveProps (newProps) {
    this.setState({
      activeSection: newProps.activeSection,
      isMobile: newProps.isMobile
    })
  }

  onTabSelect (i, e) {
    e.preventDefault()

    if (this.state.activeSection === i) {
      i = -1
    }

    this.props.setActiveSection(i)
    this.setState({ activeSection: i })

    return false
  }

  renderSection (section, i) {
    const active = this.state.activeSection

    return <li key={i} className={`m-nav-middle-li ${active === i ? 'm-nav-middle-li-on' : ''}`}>
      <a
        href={section.href}
        onClick={!section.isLink && this.onTabSelect.bind(this, i)}>
        {section.text}
        {section.extraText &&
        <span className='extra-text'>{section.extraText}</span>}
      </a>
    </li>
  }

  render () {
    return <div className='m-nav-middle'>
      <ul className='m-nav-flex-space'>
        <a href={this.props.logoLink || '/'} className='m-nav-flex-y'>
          <li className='m-nav-logo'>
            <img src={this.props.logoUrl} />
          </li>
          <li className='m-nav-tagline'>
            {this.props.tagline || 'For Giant Ideas'}
          </li>
        </a>
        <div
          className='m-nav-middle-lists m-nav-flex-xy'
          style={this.state.isMobile ? { display: 'none' } : null}>
          {this.props.sections.map(this.renderSection)}
        </div>
        <li
          onClick={this.props.toggle}
          className='m-nav-middle-toggle'>
          <button>{hamburgerIcon}</button>
        </li>
      </ul>
    </div>
  }
}

==> mongodb-ui-components-4.2.16.tgz: package/src/nav/js/nav-middle/index.js <==
import {h, Component} from 'preact'
import {hamburgerIcon} from '../nav-icons'

export default class MiddlePanel extends Component {
  constructor (props) {
    super(props)

    this.state = {
      isMobile: this.props.isMobile,
      activeSection: this.props.activeSection || -1
    }

    this.renderSection = this.renderSection.bind(this)
  }

  componentWillReceiveProps (newProps) {
    this.setState({
      activeSection: newProps.activeSection,
      isMobile: newProps.isMobile
    })
  }

  onTabSelect (i, e) {
    e.preventDefault()

    if (this.state.activeSection === i) {
      i = -1
    }

    this.props.setActiveSection(i)
    this.setState({ activeSection: i })

    return false
  }

  renderSection (section, i) {
    const active = this.state.activeSection

    return <li key={i} class={`m-nav-middle-li ${active === i ? 'm-nav-middle-li-on' : ''}`}>
      <a
        href={section.href}
        onClick={!section.isLink && this.onTabSelect.bind(this, i)}>
        {section.text}
        {section.extraText &&
        <span class='extra-text'>{section.extraText}</span>}
      </a>
    </li>
  }

  render () {
    return <div class='m-nav-middle'>
      <ul class='m-nav-flex-space'>
        <a href={this.props.logoLink || '/'} class='m-nav-flex-y'>
          <li class='m-nav-logo'>
            <img src={this.props.logoUrl} />
          </li>
          <li class='m-nav-tagline'>
            {this.props.tagline || 'For Giant Ideas'}
          </li>
        </a>
        <div
          class='m-nav-middle-lists m-nav-flex-xy'
          style={this.state.isMobile ? { display: 'none' } : null}>
          {this.props.sections.map(this.renderSection)}
        </div>
        <li
          onClick={this.props.toggle}
          class='m-nav-middle-toggle'>
          {hamburgerIcon}
        </li>
      </ul>
    </div>
  }
}
